==> SyL-0.11.4.tar.gz: SyL/include/framework/Logger/SyL_LoggerHtml.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2007 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_LoggerHtml.php,v 1.12 2007/05/20 09:43:02 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * ֥饦ؤΥϥ饹
 *
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_LoggerHtml.php,v 1.12 2007/05/20 09:43:02 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class SyL_LoggerHtml extends SyL_Logger
{
    /**
     * ֥饦˥åϤ
     *
     * @access public
     * @param string ٥̾
     * @param string å
     */
    function log($level, $message)
    {
        if ($level != '') {
            $message = sprintf('%s [%s] [%s] %s "%s %s" %s', date($this->datetime_format), SYL_ENV_TYPE, $level, $this->remote_addr, $this->request_method, $this->request_uri, rtrim($message));
        }
        if ($this->immediate || ($level == '')) {
            echo '<font color="CC0000">' . $message . '</font><br>' . $this->eof;
        } else {
            $this->buffer[] = $message;
        }
     }

}

?>

==> SyL-0.13.1.tar.gz: SyL/include/framework/Logger/SyL_LoggerHtml.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2007 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_LoggerHtml.php,v 1.13 2007/05/27 16:24:29 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * ֥饦ؤΥϥ饹
 *
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_LoggerHtml.php,v 1.13 2007/05/27 16:24:29 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class SyL_LoggerHtml extends SyL_Logger
{
    /**
     * ֥饦˥åϤ
     *
     * @access public
     * @param string ٥̾
     * @param string å
     */
    function log($level, $message)
    {
        if ($level != '') {
            $message = sprintf('%s [%s] [%s] %s "%s %s" %s', date($this->datetime_format), SYL_ENV_TYPE, $level, $this->remote_addr, $this->request_method, $this->request_uri, rtrim($message));
        }
        if ($this->immediate || ($level == '')) {
            echo '<font color="CC0000">' . $message . '</font><br>' . $this->eol;
        } else {
            $this->buffer[] = $message;
        }
     }

}

?>
